' ------------------------------------------------------------------------------------
'         			ApplyGrayscale Mask.vbs
' This script applies a grayscale mask on the selected pictures.
' The mask is a gray scale image that indicate how the origibnal image should be
' masked: white pixels will let the color go thru the mask and the black ones will
' block the color. Gray pixel will let pass a fraction of the color intensity
' depending on the intensity of the gray pixel.
' Only pictures and masks with at least 256 colors can be used.
' Masked picture are saved as JPEG files with a name combining the name of the
' original picture and the name of the mask.
' Sample grayscale masks can be found at:
'	http://graphicssoft.about.com/library/free/blfree_frames.htm
' ------------------------------------------------------------------------------------

Option Explicit

' These constants define how the contact sheets will look
'const sMaskFile = "C:\Documents and Settings\vzl7n7\Mes documents\Mes images\Mask\sc-edge065.jpg"
'const sMaskFile = "C:\Documents and Settings\vzl7n7\Mes documents\Mes images\Mask\sc-edge011.jpg"
const sMaskFile = "C:\Documents and Settings\vzl7n7\Mes documents\Mes images\Mask\sc-edge037.jpg"

const backColor = 0 '&hc0c0c0		' Background color
const sTmpMask = "c:\tmpMask.png"	' Temporary file where is resized the mask
const bFade2White = True		' Cut parts of the picture can be white or black

dim alb, pic, nbPic, i, k, picMask, picTmpMask, newPic, w, h, x, y, crP, crM, crNew, iMask, r, g, b, nRotate, sNewFileName

app.ClearTrace
set alb = app.GetCurrentAlbum
nbPic = alb.nbPicture

app.Trace "Loading mask bitmap '" & sMaskFile & "'..."
set picMask = alb.AddPicture( sMaskFile )
if picMask is Nothing then
  MsgBox "Grayscale Mask file cannot be loaded", vbOKonly or vbExclamation, "Error!!!"
elseif picMask.bpp < 8 then
  MsgBox "Grayscale Mask is not a RGB picture", vbOKonly or vbExclamation, "Error!!!"
else

k = 0
for i = 0 to nbPic-1
  Set pic = alb.GetPicture(i)
  if pic.bSelected then

    app.Trace "Processing picture " & pic.sShortFileName & "..."
    w = pic.w
    h = pic.h

    ' Adapt the size and orientation of the mask to the size and orientation of the current picture
    nRotate = 0
    if (w > h and picMask.w < picMask.h) or (w < h and picMask.w > picMask.h) then nRotate = 90
    picMask.convertAndResize2 sTmpMask, TYPE_PNG, w, h, RM_STRETCH, 0, nRotate
    set picTmpMask = alb.AddPicture( sTmpMask )

    ' Create a new empty picture
    set newPic = alb.NewPicture( w, h, 24, backColor )

    for x = 0 to w-1
      for y = 0 to h-1
	' Get the pixel from the image
	crP = pic.GetPixel( x, y )
	b = CInt( crP and &hff )
	g = CInt( fix( crP /   256 ) and &hff )
	r = CInt( fix( crP / 65536 ) and &hff )

	' Get the pixel from the mask
        crM = picTmpMask.GetPixel( x, y )
        ' It's a grayscale mask so we can take only the blue component for the intensity
        iMask = CInt( crM and &hff )

	' Compute the combined color in the target new picture
	if bFade2White then
	  crNew = CInt(255-iMask + b * iMask / 255) + CInt(255-iMask + g * iMask / 255) * 256 + CInt(255-iMask + r * iMask / 255) * 65536 
	else
	  crNew = CInt(b * iMask / 255) + CInt(g * iMask / 255) * 256 + CInt(r * iMask / 255) * 65536 
	end if
	newPic.SetPixel x, y, crNew
      next
    next

    ' Now save the masked picture using the name of the original picture and the mask name
    sNewFileName = alb.ExpandMacro( pic, "%RP" )
    x = InStrRev( sNewFileName, "." )
    sNewFileName = left( sNewFileName, x ) & alb.ExpandMacro( picMask, "%BF.jpg" )
    app.Trace " Saving masked pic as '" & sNewFileName & "'..."
    newPic.copy 0

    alb.DeletePicture newPic
    set newPic = Nothing
    alb.paste sNewFileName

    ' Remove the temporary mask from the album
    alb.DeletePicture picTmpMask
    set picTmpMask = Nothing

    k = k + 1
  end if
next

' Remove the mask from the album
alb.DeletePicture picMask
set picMask = Nothing

end if
alb.redraw
app.Trace "Done !!!"

