Option Explicit
' User may need to change these variables.
const SOURCE = 2
const DEST = 3
const SCREENWIDTH = 1024
const SCREENHEIGHT = 768

' ----------------------------------------------------
'                    BatchResize.vbs
' OverView
'
' After images are downloaded from a digital camera, the files are
' large and slow loading, which makes it difficult to compare the
' images and decide which ones to discard.  BatchResize.vbs and
' the companion script DeleteFlaggedFiles.vbs are an attempt to
' overcome this problem. The images are resized to screen size
' and placed in a different folder album, with the the file name
' of the camera image file preserved in the new album.
'
' This new album can be viewed quickly, and any discards flagged.
' A flag is a red cross in the top right of the thumbnail.  Flagging
' is achieved by Picture|Put/Remove Flag, or the hot key Ctl+k.
' Ctl+k works in slideshow mode, and is very convenient for flagging
' discards, without needing to exit the slide show.
'
' DeleteFlaggedFies is then used to delete the flagged thumbnails
' and files from both albums and folders.
'
' Example Usage
'
' To set it up, make a folder named "NewImages" and download the
' camera images to this folder.  Then make an album of these images
' and save the album in the folder NewImages.  Call it "Source.alb".
' Now make a sub folder called  "LowRes", and in this folder, make an
' album without any thumbnails, (an empty album), and save it in
' the folder "LowRes".  Call it "Destination.alb".
'
' Now exit MyAlbumPro, and then restart it.  Open "Source.alb" and then
' open "Destination.alb".  Click on "Window" on the Toolbar and you
' should see:
'
' 1. Album1
' 2. Source.alb
' 3. Destination.alb
'
' with a tick against "3. "Destination.alb"
' Click on "2. Source.alb" to view the thumbnails.  Select or flag
' the required thumbnails and then run BatchResize.vbs.
' Now, on the toolbar, Click Window|"3. Destination.alb".
' Thumbnails for the selected images should be in this album.
' Start a slideshow, and press Ctl+k on the images to be discarded.
' Exit the slideshow, and run DeleteFlaggedFiles.vbs.
' This will remove all trace of the thumbnails and files from
' both albums and folders.  (I find it convenient to select all
' remaining thumbs in "Destination.alb" and then press, Ctl+Shift+Delete
' to empty the album and remove the files.  If required, the files
' can be re-created by re-running BatchResize.vbs.
'
' Description of BatchResize.vbs
'
' BatchResize reads a Source Album, (i.e. the album containing the large
' images downloaded from the digital camera), and resizes any selected
' or flagged images.  The resized files are placed in the Destinatation
' folder and thumbnails for then are placed in the Destination album.
'
' The source and destination albums must be in different folders.
' Both albums must be in the same directory as their associated image
' files   The albums must be open.  Only JPEG files are allowed.
'
' If required, the images are resized to SCREENWIDTH x SCREENHEIGHT size.
' Images which do not exceed the screen size are copied, without change,
' to the Destination album.
'
' SCRNO is the number of the Source album as shown in the Window menu of
' MyAlbumPro.
' DESTNO is the number of the Destination album shown in the Window menu
' of MyAlbumPro.
'----------------------------------------------------
'
app.ClearTrace
const SRC = 0
const DST = 1

' Main
Dim arrsAlbum(2)			' Full Album Names
Dim intPicsResized

If IsCorrectAlbums = vbYes Then
	intPicsResized = ProcessAlb
	if intPicsResized > 0 Then
		app.Trace intPicsReSized & " pictures resized"
	End If
Else
	app.Trace "Quiting the script"
End If
' End of main


Function ProcessAlb
	Dim arrsFolder(2)		' Full folder names with trailing "\"
	Dim objAlb, objPic
	Dim intScnAspRat,  intNoPics, intCount
	Dim boolFlagged
	Dim fso
	Dim i

' Create a file system object for deleting the files.
	set fso = CreateObject("Scripting.FileSystemObject")

	GetFolderNames arrsFolder
	intScnAspRat = Fix( Round(SCREENWIDTH/SCREENHEIGHT,2)*100.0)
	set objAlb = app.GetAlbum(SOURCE - 1)
	intCount = 0
	intNoPics = objAlb.nbPicture

	For i = 0 to intNoPics - 1
		set objPic = objAlb.GetPicture(i)
		boolFlagged = objPic.lStatus And STATE_FLAGGED
		If objPic.bSelected Or boolFlagged Then
			If fso.FileExists(objPic.sFileName) Then
				intCount = intCount + 1
				ResizePic intScnAspRat, objPic, arrsFolder
			End If
		End If
	Next
	set objAlb = app.GetAlbum(DEST - 1)
	objAlb.ReDraw()
	objAlb.ReDrawFullScreen()
	ProcessAlb = intCount
End Function

'Resize the pictures as requires & put them in the Destination Album.
Function ResizePic (intScnAspRat, objPic, arrsFolder)
	Dim intWid, intHt, intAspRat
	Dim strPicName
	Dim objAlb
	Dim boolAns

	intHt = objPic.h
	intWid = objPic.w

	If intWid < SCREENWIDTH And intHt < SCREENHEIGHT Then
		intWid = 0
		intHt = 0
	Else
		intAspRat = Int( Round(intWid/intHt,2)*100.0)
		If intAspRat = intScnAspRat Then
			intWid = SCREENWIDTH
			intHt = SCREENHEIGHT
		ElseIf intAspRat > intScnAspRat Then
		' Width needs most adjustment.
			intHt =  Fix(Round(intHt * SCREENWIDTH/intWid, 0))
			intWid = SCREENWIDTH
		Else				' Height needs most adjustment.
			intWid = Fix(Round(intWid*SCREENHEIGHT/ intHt, 0))
			intHt = SCREENHEIGHT
		End If
	End If

	strPicName = arrsFolder(DST) & objPic.sShortFileName
	boolAns = objPic.ConvertAndResize(strPicName, TYPE_JPEG, intWid, intHt)

	set objAlb = app.GetAlbum(DEST - 1 )
	objAlb.AddPicture(strPicName)
End Function
			
' Get the folder names from the album names.
' The folder names contain the trailing "\"
Function GetFolderNames (arrsFolder)
	Dim intPos

	intPos = InStrRev(arrsAlbum(SRC), "\", -1)
	arrsFolder(SRC) = mid(arrsAlbum(SRC), 1, intPos)
	intPos = InStrRev(arrsAlbum(DST), "\", -1)
	arrsFolder(DST) = mid(arrsAlbum(DST), 1, intPos)
End Function
	
' Get the album names and  check that the Source and Destination
' albums are correct.
Function IsCorrectAlbums
	Dim strStr
	Dim objAlb

	set objAlb = app.GetAlbum(SOURCE - 1)
	arrsAlbum(SRC) = objAlb.FullName
	set objAlb = app.GetAlbum(DEST - 1)
	arrsAlbum(DST) = objAlb.FullName
	strStr = "Source File: " & arrsAlbum(SRC) & chr(13)
	strStr = strStr & "Destination File: " & arrsAlbum(DST) & chr(13)
	strStr = strStr & "Proceed?"
	IsCorrectAlbums = MsgBox (strStr, vbYesNo, "DeleteFlaggedFiles")
End Function
