#--------------------------------------------------------------------------
#			Set_IPTC_ByLine.pls
# This script lists the defined IPTC fields stored in JPEG pictures.
# It uses the IPTCInfo package from Josh Carter that can be downloaded from
#	http://multipart-mixed.com/photo/iptc.html
# Note: Only the selected pictures are listed and the listing shows only
#       the most common IPTC fields.
#--------------------------------------------------------------------------

use Image::IPTCInfo;
use File::Copy;

# Load the MyAlbum constants so they can be used in the script
#use Win32::OLE::Const 'MyAlbum';
# no... too slow! let's just redefine the constants we are using in the script
use constant TYPE_JPEG => 2;
use constant TRACE_ARROW => 9;
use constant TRACE_INFORMATION => 0;
use constant TRACE_OK => 1;
use constant TRACE_WARNING => 2;
use constant TRACE_ERROR => 3;

$App->ClearTrace();

$alb = $App->GetCurrentAlbum();
$nb = $alb->nbPicture;
$App->Trace( "Pictures in this album: $nb", -1, TRACE_INFORMATION );
$App->Trace( "Note: only the selected JPEG pictures with IPTC info are listed", -1, TRACE_WARNING );

for ($i = 0; $i < $nb; $i++) {
    $pic = $alb->GetPicture($i);
    if ($pic->bSelected && ($pic->lStatus & 0xff) == TYPE_JPEG) {
      $filename = $alb->ExpandMacro( $pic, "%RP" );

      # Create new IPTCInfo object for the file
      my $info = new Image::IPTCInfo( $filename );
      if (defined($info)) {
        $App->Trace( "file\t\t\t\t$filename",255*256*256, TRACE_ARROW );
	# list specific attributes
	displayAttribute( $info, 'headline' );
	displayAttribute( $info, 'caption/abstract' );
	displayAttribute( $info, 'object name');
	displayAttribute( $info, 'category' );
	my $suppCatsRef = $info->SupplementalCategories();
	$s = "";
	foreach $suppCat (@$suppCatsRef) {
	  if ($s ne "") { $s = $s . ";  " }
	  $s = $s . $suppCat
	}
	$s ne "" &&  $App->Trace( "  supplemental categories\t$s" );
	displayAttribute( $info, 'date created' );
	displayAttribute( $info, 'time created' );
	displayAttribute( $info, 'city');
	displayAttribute( $info, 'province/state');
	displayAttribute( $info, 'country/primary location code' );
	displayAttribute( $info, 'country/primary location name');
	displayAttribute( $info, 'original transmission reference');
	displayAttribute( $info, 'by-line');
	displayAttribute( $info, 'by-line title' );
	displayAttribute( $info, 'credit');
	displayAttribute( $info, 'source');
	displayAttribute( $info, 'copyright notice' );
	displayAttribute( $info, 'contact');
	displayAttribute( $info, 'contact' );

	
	displayAttribute( $info, 'writer/editor');
	displayAttribute( $info, 'special instructions');
	 
	# With this you can get a list of keywords...
	my $keywordsRef = $info->Keywords();
	$s = "";
	foreach $keyword (@$keywordsRef) {
	  if ($s ne "") { $s = $s . ";  " }
	  $s = $s . $keyword	  
	}
	$s ne "" && $App->Trace( "  keyword\t\t\t$s" );
     }
     else {
      	#$App->Trace( "warning: " . Image::IPTCInfo::Error(), -1, TRACE_WARNING );
     }
   }
}

$App->Trace( "all done!", 255*256*256, TRACE_OK );
exit;

sub displayAttribute
{
  local ($zInfo, $zAttrib) = @_;
  $line = "  " . $zAttrib . "\t";
  length $zAttrib < 24 and ($line = $line . "\t");
  length $zAttrib < 16 and ($line = $line . "\t");
  length $zAttrib <  8 and ($line = $line . "\t");
  $a = $zInfo->Attribute($zAttrib);
  $a ne '' &&  $App->Trace( $line . $a );
}

