'--------------------------------------------------------------------------
'				VCDbuilder.vbs
' Build VCD and SVCD with this script!
' You will need first to install the free VCDEasy package that can be found
' at http://www.vcdeasy.org/. Well now, it is not as free as it used to be,
' but the "free limited version" is enough for the script as it uses only the
' FREE tools that are included in VCDEasy: Mjpegtools for MPEG compression
' and VCDImager for generating the VCD image.
' The script will generate BIN/CUE image files that can be burnt to a CD.
' You have the choice between VCD 2.0 and SVCD 1.0, both offering 704x576
' "high" picture resolution for PAL TV.
' The CD can contain only the pictures (that will be played in sequence)
' or the pictures and a set of menu pages that can be use to easily access
' a large set of pictures. This menu pages can be built from the Contact
' Sheet generated by the Tool > Export Album command (or the
' SimpleContactSheet.vbs script).
' Video can be included if they are to a MPEG format suitable for (S)VCD. The
' album can reference .mpg video files or other video format as long as there
' is also a MPEG file with the same name (eg: Vid001.avi and Vid001.mpg) in
' the same folder.
' To build a (S)VCD:
' - Open your album and select the pictures you want to include on the CD.
'   Note that it must be a bitmap pictures or a video (other formats not
'   supported).
' - Create a new empty folder that will be used for the temporary files
'   (for instance d:\tmpVCD). That will be our work folder.
' - If you want to have menu pages, build the contact sheets for the
'   selected pictures and save them in the work folder.
' - Start the script, a dialog box will open offering some settings:
'	. selection between VCD and SVCD.
'	. as TV generally do not show the full resolution, you can specify
'	  the size of the black margin around each picture.
'	. Enter the same number of thumbnails per page as in the generated
'	  contact sheets.
' The script can take some time to process: convert the pictures and the
' contact sheets to MPEG, build the XML project file and generate the VCD
' image files.
' The script can be further customized by modifying the first block of
' constants (and the rest of the code if you want too!).
'--------------------------------------------------------------------------
Option Explicit

const sVCDEasyFolder = "C:\Program Files\VCDEasy\"	' Folder of the VCDEasy package (change if necessary)
const sTempFolder = "d:\tmpVCD\"			' Output folder where the generated files will be written
							' (must also contain the menu contact-sheets if needed)
const sDSPictInfo = "     %C7 - %LE[%C1,5] %LE[%C2,5] - %1C"			' Display String for the picture comment, set to an empty
							' string to disable the printing of text on the pictures.
const sPictureInfoFont = "Arial,48,10,400,0,0,0"	' Font used for the picture comment
const crPictInfo = &hff0000				' Color of the picture comment
const crPictInfoShadow = &hc0c0c0			' Color of the shadow of the picture comment
const crBackground = &h000000				' Background color (around the pictures)
const sCSFileType = ".jpg"
const bUselkVCDimager = True				' Use lkVCDimager instead of the standard one (ISO Level 2 suppoo
const wVCD = 704, hVCD = 576				' PAL still-image size for VCD 2.0 & SVCD
'const wVCD = 704, hVCD = 480				' NTSC still-image size for VCD 2.0 & SVCD
const nFrameSize = 220					' Max Size of each MPEG frame (in KB, max is 200)
'const xTVRatio = 0.9167				' Aspect ratio correction for Monitor -> PAL TV
'const xTVRatio = 1.1					' Aspect ratio correction for Monitor -> NTSC TV


' Do not changes these constants!
const TYPE_VCD2 = 2, TYPE_SVCD = 3
Const DT_TOP = &H0		' Specifies top-justified text (single line only).
Const DT_LEFT = &H0		' Aligns text flush-left.
Const DT_CENTER = &H1		' Centers text horizontally.
Const DT_RIGHT = &H2		' Aligns text flush-right.
Const DT_VCENTER = &H4		' Specifies vertically centered text (single line only).
Const DT_BOTTOM = &H8		' Specifies bottom-justified text (single line only).
Const DT_SINGLELINE = &H20	' Specifies single line only. Carriage returns and
Const DT_NOPREFIX = &H800	' Turns off processing of prefix characters.
Const DT_CALCRECT = &H400	' Determines the width and height of the rectangle.
Const ForReading = 1, ForWriting = 2
const crBlue = &hff0000

Dim alb, pic, fso, oShell, sScriptFolder, sCmdFile, nRunMode, sFile, sAlbumBaseName, sXMLFile
Dim nType, nTVMargin, bAutoSlideShow, bBuildMPEG, bUseMenuPages, bBuildMPEGMenu, nbPerCS, bBuildXML, bBuildVCD
Dim sIsoFolder(), bAddISOFiles
Dim domdoc 'As New DOMDocument
Dim bDebugMode		' Trace the execution of the external tools.

app.ClearTrace
set alb = app.GetCurrentAlbum
if not alb is Nothing then

  nRunMode = &h10000	' Execute external apps in synchonous mode
  
  Set fso = CreateObject("Scripting.FileSystemObject")
  Set oShell = CreateObject("Shell.Application")

  Dim nbPic, i, k, kk, nbSelPic, sCmd, f, nbCS
  nbPic = alb.nbPicture
  nbSelPic = alb.nbSelectedPicture
  if nbPic = 0 or nbSelPic = 0 then
    MsgBox "No picture selected in this album!", vbOKonly or vbExclamation, "Error!!!"
  else
    app.Trace "Pictures selected in this album: " & nbSelPic, crBlue, TRACE_INFORMATION
    sAlbumBaseName = alb.ExpandMacro( Nothing, "%AF" )
    k = InStrRev( sAlbumBaseName, "." )
    if k > 0 then
      sAlbumBaseName = Left( sAlbumBaseName, k - 1 )
      sXMLFile = sTempFolder & "videocd.xml"
      sScriptFolder = app.sScriptFile
      k = InStrRev( sScriptFolder, "\" )
      sScriptFolder = left( sScriptFolder, k )
      if GetOptions then
        if bDebugMode then nRunMode = &h10001
        ProcessPictures
      end if
    else
      MsgBox "Album needs to be saved first!", vbOKonly or vbExclamation, "Error!!!"
    end if
  end if
end if
alb.redraw
app.Trace "Done !", -1, TRACE_GREENDOT


'--------------------------------------------------------------------------
sub ProcessPictures
' Process each selected picture
if bBuildMPEG then
  app.Trace "Converting the pictures to MPEG files...", crBlue, TRACE_INFORMATION
  k = 0
  for i=0 to nbPic-1
    Set pic = alb.GetPicture(i)
    if pic.bSelected then
      if (pic.lStatus and &hff) <> TYPE_VID then
        app.Trace "    Converting " & pic.sShortFileName & "..."
        ConvertPicture pic, (sDSPictInfo <> ""), False
      else
        app.Trace "    Using video file " & pic.sShortFileName & "..."
	if not CheckVideo( alb, pic ) then
	  app.Trace "      Caution: no MPEG file for " & pic.sShortFileName, -1, TRACE_WARNING
	end if
      end if
    end if
  next 
else
    k = alb.nbSelectedPicture
end if

' Convert the contact-sheets to menu pages
dim sCSFile, bTempPic
nbCS = alb.nbSelectedPicture / nbPerCS
if nbCS <> Fix(nbCS) then nbCS = Fix(nbCS) + 1
app.Trace "Number of menu pages: " & nbCS, crBlue, TRACE_INFORMATION
'app.Trace bBuildMPEGMenu & vbtab & bUseMenuPages
if bBuildMPEGMenu and bUseMenuPages then
  for i = 1 to nbCS
    sCSFile = GetCSName( i )
    bTempPic = False
    if fso.FileExists( sTempFolder & sCSFile ) then
      set pic =  alb.GetPictureByFileName( sCSFile )
      if pic is Nothing then
        bTempPic = True
        set pic = alb.AddPicture( sTempFolder & sCSFile )
      end if
      app.Trace "    Converting contact-sheet " & sTempFolder & sCSFile & "..."
      ConvertPicture pic, True, True
      alb.DeletePicture pic
    else
      app.Trace ">>> Error: cannot find contact-sheet '" & sTempFolder & sCSFile & "'", -1, TRACE_ERROR
    end if
  next  
end if

' Now generate the XML file
if k > 0 then
if bBuildXML then
app.Trace "Building the project XML file...", crBlue, TRACE_INFORMATION
set domdoc = CreateObject("MSXML.DOMDocument")

Dim videocd, item, itemP, itemK, s
Set videocd = domdoc.createElement("videocd")
domdoc.appendChild videocd
videocd.setAttribute "xmlns", "http://www.gnu.org/software/vcdimager/1.0/"
if nType = TYPE_VCD2 then
  videocd.setAttribute "class", "vcd"
  videocd.setAttribute "version", "2.0"
else
  videocd.setAttribute "class", "svcd"
  videocd.setAttribute "version", "1.0"
end if
set item = AddItem( videocd, "option", "" )
item.setAttribute "name", "relaxed aps"
item.setAttribute "value", "false"

s = UCase(Replace( alb.sAlbumTitle, " ", "_" ))
s = Replace( s, ".", "" )
set item = AddItem( videocd, "info", "" )
  AddItem item, "album-id", s
  AddItem item, "volume-count", "1"
  AddItem item, "volume-number", "1"
  AddItem item, "restriction", "1"

set item = AddItem( videocd, "pvd", "" )
  'if len(s) > 
  AddItem item, "volume-id", s
  AddItem item, "system-id", "CD-RTOS CD-BRIDGE"
  AddItem item, "application-id", "CDI/CDI_VCD.APP;1"
  AddItem item, "preparer-id", ""
  AddItem item, "publisher-id", "MYALBUM"

' Add files to the ISO part
if bAddIsoFiles then
  for kk = LBound( sIsoFolder ) to UBound( sIsoFolder )
    AddIsoFiles videocd, sIsoFolder(kk)
  next
end if

set item = AddItem( videocd, "segment-items", "" )

if bUseMenuPages then
  for i = 0 to nbCS-1
    sCSFile = sTempFolder & GetCSName( i+1 )
    kk = InStrRev( sCSFile, "." )
    sCSFile = left( sCSFile, kk ) & "mpg"
    'app.Trace sCSFile
    if fso.FileExists( sCSFile ) then
      set itemP = AddItem( item, "segment-item", "" )
      itemP.setAttribute "src", sCSFile
      itemP.setAttribute "id", "Menu-" & GetNum( i, 4 )
    end if
  next
end if

k = 0
nbPic = alb.nbPicture
for i = 0 to nbPic-1
  Set pic = alb.GetPicture(i)
  if pic.bSelected then
    if (pic.lStatus and &hff) <> TYPE_VID then    
      sFile = sTempFolder & pic.sShortFileName
      kk = InStrRev( sFile, "." )
      sFile = left( sFile, kk ) & "mpg"
    else
      sFile = alb.ExpandMacro( pic, "%RP" )
      kk = InStrRev( sFile, "." )
      sFile = Left( sFile, kk ) & "mpg"      
    end if
    set itemP = AddItem( item, "segment-item", "" )
    itemP.setAttribute "src", sFile
    itemP.setAttribute "id", "Segment-" & GetNum( k, 4 )
    k = k+1
  end if
next

if nType = TYPE_VCD2 then
  s = sScriptFolder & "MyAlbum-VCD2b.mpg"
else
  s = sScriptFolder & "MyAlbum-SVCD.mpg"
end if
if not fso.FileExists( s ) then
  if nType = TYPE_VCD2 then
    s = sVCDEasyFolder & "Extra\PhotoVCD2-PAL.mpg"
  else
    s = sVCDEasyFolder & "Extra\PhotoSVCD-PAL.mpg"
  end if
end if
  set item = AddItem( videocd, "sequence-items", "" )
  set itemK = AddItem( item, "sequence-item", "" )
  itemK.setAttribute "src", s
  itemK.setAttribute "id", "Sequence-" & GetNum( k, 4 )
  set itemP = AddItem( itemK, "default-entry", "" )
  itemP.setAttribute "id", "Chapter-" & GetNum( k, 4 ) & "-01"

set item = AddItem( videocd, "pbc", "" )
if bUseMenuPages then
  for k = 0 to nbCS-1
    set itemP = AddItem( item, "selection", "" )
    itemP.setAttribute "id", "SelectionMenu-" & GetNum( k, 3 )
    AddItem itemP, "bsn", "1"
    set itemK = AddItem( itemP, "prev", "" )
    if k > 0 then
      itemK.setAttribute "ref", "SelectionMenu-" & GetNum( k-1, 3 )
    else
      itemK.setAttribute "ref", "SelectionMenu-" & GetNum( nbCS-1, 3 )
    end if

    set itemK = AddItem( itemP, "next", "" )
    if k < nbCS-1 then
      itemK.setAttribute "ref", "SelectionMenu-" & GetNum( k+1, 3 )
    else
      itemK.setAttribute "ref", "SelectionMenu-000"
    end if

    set itemK = AddItem( itemP, "return", "" )
    itemK.setAttribute "ref", "SelectionMenu-000"

    set itemK = AddItem( itemP, "timeout", "" )
    if k = 0 then
      ' Start on the first picture on time-out on the first menu page
      itemK.setAttribute "ref", "Selection-" & GetNum( 0, 3 )
    else
      itemK.setAttribute "ref", "Selection-end"
    end if
    
    s = "30"
    if k > 0 or not bAutoSlideShow then s = "-1"
    set itemK = AddItem( itemP, "wait", s )
    set itemK = AddItem( itemP, "loop", "1" )
    itemK.setAttribute "jump-timing", "immediate"

    set itemK = AddItem( itemP, "play-item", "" )
    itemK.setAttribute "ref", "Menu-" & GetNum( k, 4 )

    kk = (k+1) * nbPerCS -1
    if kk >= alb.nbSelectedPicture then kk = alb.nbSelectedPicture - 1
    for i = k * nbPerCS to kk
      set itemK = AddItem( itemP, "select", "" )
      itemK.setAttribute "ref", "Selection-" & GetNum( i, 3 )
    next
  next
end if

k = 0
for i=0 to nbPic-1
  Set pic = alb.GetPicture(i)
  if pic.bSelected then

    'sFile = sTempFolder & pic.sShortFileName
    'kk = InStrRev( sFile, "." )
    'sFile = left( sFile, kk ) & "mpg"
    
    set itemP = AddItem( item, "selection", "" )
    itemP.setAttribute "id", "Selection-" & GetNum( k, 3 )
    AddItem itemP, "bsn", "1"
    set itemK = AddItem( itemP, "prev", "" )
    if k > 0 then
      itemK.setAttribute "ref", "Selection-" & GetNum( k-1, 3 )
    else
      if bUseMenuPages then
        itemK.setAttribute "ref", "SelectionMenu-000"
      else
        itemK.setAttribute "ref", "Selection-end"
      end if
    end if

    set itemK = AddItem( itemP, "next", "" )
    if k < nbSelPic-1 then
      itemK.setAttribute "ref", "Selection-" & GetNum( k+1, 3 )
    else
      if bUseMenuPages then
        itemK.setAttribute "ref", "SelectionMenu-000"
      else
        itemK.setAttribute "ref", "Selection-end"
      end if
    end if

    set itemK = AddItem( itemP, "return", "" )
    if bUseMenuPages then
      itemK.setAttribute "ref", "SelectionMenu-" & GetNum( k \ nbPerCS, 3 )
    else
      itemK.setAttribute "ref", "Selection-end"
    end if

    set itemK = AddItem( itemP, "timeout", "" )
    itemK.setAttribute "ref", "Selection-end"
    if k < nbSelPic-1 then
      itemK.setAttribute "ref", "Selection-" & GetNum( k+1, 3 )
    else
      if bUseMenuPages then
        itemK.setAttribute "ref", "SelectionMenu-000"
      else
        itemK.setAttribute "ref", "Selection-end"
      end if
    end if
    
    set itemK = AddItem( itemP, "wait", GetPicDelay(pic) )
    set itemK = AddItem( itemP, "loop", "1" )
    itemK.setAttribute "jump-timing", "immediate"

    set itemK = AddItem( itemP, "play-item", "" )
    itemK.setAttribute "ref", "Segment-" & GetNum( k, 4 )

    set itemK = AddItem( itemP, "select", "" )
    itemK.setAttribute "ref", "Selection-" & GetNum( k, 3 )
 
    k = k+1
  end if
next
set itemK = AddItem( item, "endlist", "" )
itemK.setAttribute "id", "Selection-end"
itemK.setAttribute "rejected", "true"

' Save the XML stream in a file for VCDImager
Set f = fso.OpenTextFile( sXMLFile, ForWriting, True )
f.WriteLine "<?xml version=""1.0""?>"
f.WriteLine "<!DOCTYPE videocd PUBLIC ""-//GNU//DTD VideoCD//EN"" ""http://www.gnu.org/software/vcdimager/videocd.dtd"">"
f.WriteLine domdoc.xml
f.close
'domdoc.save sTempFolder & "videocd.xml"

' Show the produced XML file
if bDebugMode then app.Run sXMLFile, True, 1
end if		' bBuildXML 

if bBuildVCD then
  ' Pass the XML file to VCDImager
  app.Trace "Building VCD image...", crBlue, TRACE_INFORMATION
  sCmdFile = sTempFolder & "vcdX.cmd"
  Set f = fso.OpenTextFile( sCmdFile, ForWriting, True )
  sCmd = """" & sVCDEasyFolder & "vcdimager\"
  if bUselkVCDimager then sCmd = sCmd & "lk"
  sCmd = sCmd & "vcdxbuild.exe"" -p -c " & sTempFolder & "videocd.cue -b " & sTempFolder & "videocd.bin " 
  'sCmd = sCmd & "-i iso "
  if bUselkVCDimager then sCmd = sCmd & "-x "
  sCmd = sCmd & sXMLFile
  f.WriteLine sCmd
  f.WriteLine "if ErrorLevel 1 goto Error"
  f.WriteLine "goto End"
  f.WriteLine ":Error"
  'f.WriteLine "Pause"
  if bDebugMode then f.WriteLine "Pause"
  f.WriteLine "exit 1"
  f.WriteLine ":End"
  f.close
  if app.Run( sCmdFile, False, nRunMode) > 0 then
    app.Trace ">>> Error building VCD image!", -1, TRACE_ERROR
  else
    MsgBox "VCD build is now complete!" & vbCRLF & _
    "A 'videocd.cue' file and a 'videocd.bin' file have been written in the '" & sTempFolder & "' folder." & vbCRLF & _
    "Use your favorite CD burning application to burn the VCD (command ""Burn image"" and select the cue file).", _
    vbOKonly or vbInformation, "OK !"
  end if
end if
end if 	' k > 0

end sub

'--------------------------------------------------------------------------
function AddItem( byref obj, byref sName, byref sValue )
  dim item
  set item = domdoc.createElement( sName )
  obj.appendChild item
  if sValue <> "" then item.text = sValue
  set AddItem = item
end function

'--------------------------------------------------------------------------
function GetNum( byval k, byval nbDigit )
  dim s
  s = CStr( k )
  while len(s) < nbDigit
    s = "0" & s
  wend
  GetNum = s
end function

'--------------------------------------------------------------------------
function GetPicDelay( byref pic )
  if bAutoSlideShow then
    dim n
    if (pic.lStatus and &hff) <> TYPE_VID then
      n = pic.lTransition and &hffff
      if n = 65535 then n = alb.nDelaySlideshow
      n = CInt(n /10)
      if n = 0 then n = 1
      GetPicDelay = CStr(n)
    else
      GetPicDelay = 1	' 1 second for videos
    end if
  else
    GetPicDelay = -1
  end if
end function

'--------------------------------------------------------------------------
function ConvertPicture( byref pic, byval bStamp, byval bIsMenu )
    dim sFileBase, sFileR, sFileTemp, sFileMPEG
    sFileBase = sTempFolder & pic.sShortFileName
    kk = InStrRev( sFileBase, "." )
    sFileBase = left( sFileBase, kk-1 )
    sFileR = sFileBase & "_R.jpg"
    sFileTemp = sFileBase & "_T.mpg"
    sFileMPEG = sFileBase & ".mpg"
    
    if ResizePicture( pic, bStamp, bIsMenu, sFileR ) then
      sCmdFile = sTempFolder & "vcd.cmd"
      Set f = fso.OpenTextFile( sCmdFile, ForWriting, True )
      sCmd = """" & sVCDEasyFolder & "Mjpegtools\jpeg2yuv.exe"" -n 1 -f 25 -j """ & sFileR & """ -I p -L 0 | "
      sCmd = sCmd & """" & sVCDEasyFolder & "Mjpegtools\mpeg2enc.exe"" -T " & nFrameSize & " -f "
      if nType = TYPE_VCD2 then
        sCmd = sCmd & "6"
      else
        sCmd = sCmd & "7"
      end if
      sCmd = sCmd & " -a 2 -o """ & sFileTemp & """"
'app.Trace sCmd
      f.WriteLine sCmd
      f.WriteLine "if ErrorLevel 1 goto Error"
      
      sCmd = """" & sVCDEasyFolder & "Mjpegtools\mplex.exe"" -f "
      if nType = TYPE_VCD2 then
        sCmd = sCmd & "6"
      else
        sCmd = sCmd & "7"
      end if
      sCmd = sCmd & " -o """ & sFileMPEG & """ """ & sFileTemp & """"
      f.WriteLine sCmd
      f.WriteLine "if ErrorLevel 1 goto Error"
      f.WriteLine "goto End"
      f.WriteLine ":Error"
      if bDebugMode then f.WriteLine "Pause"
      f.WriteLine "exit 1"
      f.WriteLine ":End"
      f.WriteLine "del """ & sFileR & """"
      f.WriteLine "del """ &sFileTemp & """"

      f.close
      if app.Run( sCmdFile, False, nRunMode ) <> 0 then
	app.Trace ">>> Error converting picture to MPEG", -1, TRACE_ERROR
	pic.bSelected = False
      else
	k = k + 1
      end if
    else
      ' If we cannot convert the picture, unselect it so it will not be used any longuer in the script
      app.Trace ">>> Error resizing picture", -1, TRACE_ERROR
      pic.bSelected = False
    end if
    pic.SetTextStampInfo "", "", 0, 0, 0	' Reset the stamp info
    ConvertPicture = True
end function

'--------------------------------------------------------------------------
function ResizePicture( byref pic, byval bStamp, byval bIsMenu, byval sNewFile )
  ResizePicture = False
  dim tempPic, s
  dim xS, yS, dx, dy

  xS = CInt( (100 - nTVMargin) * wVCD / 100 )
  yS = CInt( (100 - nTVMargin) * hVCD / 100 )
  dx = CInt( (wVCD - xS) / 2 )
  dy = CInt( 3 * (hVCD - yS) / 4 )	' Wider border on top
'app.trace dx & vbTab & dy  & vbTab & xS  & vbTab & yS

  if pic.resize( xS, yS, RM_EXACTSIZE, crBackground, 0 ) then
    ' Create a temporary picture with a black margin for the TV
    set tempPic = alb.NewPicture( wVCD, hVCD, 24, crBackground )
    pic.Copy 0
    pic.load False
    tempPic.Paste dx, dy
    
    if bStamp then
      ' Print some info on the picture:
      '	 - at the bottom for the photos
      '	 - the upper-left corner for the menu pages
      if pic.w / pic.h > wVCD / hVCD then
        ' Picture is wider than the screen and has a wider bottom margin
	'yS = pic.h / pic.w * xS
	'dy = CInt( (hVCD - yS) / 2 )
      end if

      dim rect, nFormat
      set rect = CreateObject("MyAlbum.rect")
      rect.x = dx+4
      rect.y = dy
      rect.w = xS-8
      rect.h = yS
      
      nFormat = DT_NOPREFIX or DT_SINGLELINE
      if bIsMenu then
        s = i & "/" & nbCS
        nFormat = nFormat or DT_TOP or DT_RIGHT
        rect.y = rect.y + 15
      else
        s = alb.ExpandMacro( pic, sDSPictInfo )
        nFormat = nFormat or DT_BOTTOM or DT_LEFT
      end if
      ' Draw the shadow of the text
      tempPic.drawText s, rect, sPictureInfoFont, crPictInfoShadow, -1, nFormat
      ' Offset the drawing rectangle and draw the text
      rect.x = rect.x - 2
      rect.y = rect.y - 2
      tempPic.drawText s, rect, sPictureInfoFont, crPictInfo, -1, nFormat
      'tempPic.DrawRectangle rect, 2, 255, -1, DRAWRECT_RECT, 0, 0
      set rect = nothing
    end if
    
    ' Now save the new picture in the temp folder
    if tempPic.Save( sNewFile, False ) then ResizePicture = True
    alb.DeletePicture tempPic 
    set tempPic = Nothing
  end if
  pic.Load False
end function

'--------------------------------------------------------------------------
function GetCSName( num )
  GetCSName = "CS_" & sAlbumBaseName & "_" & GetNum( num, 2 ) & sCSFileType
end function

'--------------------------------------------------------------------------
function GetOptions()
  Dim sTemplateString, sHTMLFile
  ' Normally the HTML file for the dialog is in the same folder as the current script...
  sHTMLFile = sScriptFolder & "VCDbuilder-GetOptions.html"
  sTemplateString = app.HTMLDialog( sHTMLFile, "", "dialogWidth:380px;dialogHeight:420px" )
  if sTemplateString <> "" and sTemplateString <> "-" then
    ParseOptions sTemplateString
    GetOptions = True
  else
    GetOptions = False
  end if
end function

'--------------------------------------------------------------------------
function ParseOptions( sOpt )
  'app.trace sOpt
  dim T, k
  T = Split( sOpt, ",", -1, 1 )
  
  nType = TYPE_VCD2
  if CInt(trim(T(0))) = 1 then nType = TYPE_SVCD
  nTVMargin = CInt( T(1) )

  bBuildMPEG = False
  if CInt(trim(T(2))) = 1 then bBuildMPEG = True
  bUseMenuPages = False
  if CInt(trim(T(3))) = 1 then bUseMenuPages = True
  bBuildMPEGMenu = False
  if CInt(trim(T(4))) = 1 then bBuildMPEGMenu = True
  nbPerCS = CInt( T(5) )
  bBuildXML = False
  if CInt(trim(T(6))) = 1 then bBuildXML = True
  bBuildVCD = False
  if CInt(trim(T(7))) = 1 then bBuildVCD = True
  bAutoSlideShow = False
  if CInt(trim(T(8))) = 1 then bAutoSlideShow = True

  bDebugMode = False
  if CInt(trim(T(9))) = 1 then bDebugMode = True
  
  ' List of folders to add to the ISO filesystem
  k = 10
  if k <= UBound(T) then
    bAddISOFiles = True
    'app.Trace UBound(T)-k
    ReDim sIsoFolder(UBound(T)-k)
    for k = 10 to UBound(T)
      sIsoFolder(k - 10) = Trim(T(k))
    next
  else
    bAddISOFiles = False
  end if
end function


'--------------------------------------------------------------------------
sub AddIsoFiles( byref videocdItem, byval sFolder )
  dim ik, sFolderName, item, itemF
  ik = InStrRev( sFolder, "\" )
  sFolderName = Mid( sFolder, ik+1 )
  app.Trace "Adding folder '" & sFolder & "' to the ISO file-system...", crBlue, TRACE_INFORMATION
  set item = AddItem( videocdItem, "filesystem", "" )
  set itemF = AddItem( item, "folder", "" )
  AddItem itemF, "name", sFolderName
  browseFolder sFolder, itemF, 1
end sub

'--------------------------------------------------------------------------
Function browseFolder( byval sFolderName, byref itemF, byVal nLevel )
  dim f, itemFile, ik, sFile, itemFZ
  set f = oShell.NameSpace( sFolderName & "\" )
  if f is Nothing then
    app.Trace ">>> Error adding folder '" & sFolderName & "'", -1, TRACE_ERROR
    exit function
  else
    ' Add the sub-folders first
    for each itemFile in f.items
      if itemFile.isfolder then
	dim itemSubFolder
	app.Trace "  Subfolder: " & itemFile.Path
	set itemSubFolder = AddItem( itemF, "folder", "" )
	AddItem itemSubFolder, "name", itemFile.name
	browseFolder itemFile.Path, itemSubFolder, nLevel+1
        'browseFolder item.path, nLevel+1
      end if
    next
    ' Then the files
    for each itemFile in f.items
      if not itemFile.isfolder then
	sFile = itemFile.name
	ik = InStrRev( sFile, "." )
	if len(sFile)-ik > 3 then sFile = left(sFile, len(sFile)-1 )
	'app.Trace sFile
	set itemFZ = AddItem( itemF, "file", "" )
	itemFZ.setAttribute "src", itemFile.Path
	AddItem itemFZ, "name", sFile
      end if
    next
  end if
End Function


Function CheckVideo( byref alb, byref pic )
  dim sFile, k
  sFile = alb.ExpandMacro( pic, "%RP" )
  k = InStrRev( sFile, "." )
  sFile = Left( sFile, k ) & "mpg"
  CheckVideo = True
  if not fso.FileExists( sFile ) then CheckVideo = False
End Function

' VCD: (352x288 @25Hz PAL)
' sh -c "./jpeg2yuv -f 25 -Ip -L0 -j T_%%03d.jpg -b 1 | ./mpeg2enc -f1 -o out.mpg"
' mplex -f1 -o tVCD.mpg out.mpg

' SVCD: (480x576 @25Hz PAL) / xSVCD: 720x480 ???
' sh -c "./jpeg2yuv -f 25 -Ip -L0 -j T_%%03d.jpg -b 1 | ./mpeg2enc -f4 -o out.m2v"
' mplex -f4 -o tSVCD.mpg out.m2v

