' ------------------------------------------------------------------------------------
'					jps2stereoview.vbs
' Create an stereocard from a JPS or jpeg crossview format file
' This script takes the current picture and generates a new one with:
'  - left and right images are arranged to print the stereocard
'  - the comment of the picture is printed on the picture
'  - its name is derived from the original picture with stereocard type appended.
'
' Author: Jose Carlos Fernandez (josecarlosfernandez@terra.es)
'	  http://www.geocities.com/josecarlosfernandez/
' (c)2002
'
' ----------------- BEGIN: TO DO LIST --------------------------------------------
' - Investigate on how to print vertical text for Holmes Card
' - Calculate best aperture setting for Realist mount
' - Add selection box for lossy (JPG) or lossless (TIFF/BMP) output compression scheme
' - Add better support for text layout, more lines and configurable position
' ----------------- END: TO DO LIST --------------------------------------------
'
' Version 2.0c (2002/03/19)
' ---------------------------------------------
' - Text is shown in the botton of right image in Holmes stereocard
' - Added crop option, the images are cropped to fill the maximun image area
' - Cancel button works properly in input box
' ---------------------------------------------
'
' Version 2.0b
' ---------------------------------------------
' Fixed: left and right images where both left image
' ---------------------------------------------
'
' Version 2.0a
' ---------------------------------------------
' Now 5 stereocard formats are supported:
'   new Holmes (Thorpe standard)
'   new Holmes cabinet (Thorpe standard)
'   thorpe 6x13 (Thorpe standard)
'   classic Holmes stereocard
'   6x13 eurocard
'
' - add a prefix indicating card type
'
' jps2thorpecard (former name) Version 1.1a
' ------------------------------------------------------------------------------------
' - Now calculates the left and right image position correctly
' - If no comment in the picture, Cabinet card format is used
' - Up to three comment lines are printed
' - Accept jpeg files with .jps extension (Add to album using Ctrl+drag'n'drop)
' - Bach conversion (multiple selected files) feature added
' ------------------------------------------------------------------------------------
'
' jps2thorpecard (former name) Version 1.0
' ------------------------------------------------------------------------------------
' First released version
' ------------------------------------------------------------------------------------

Option Explicit

const sCommentDS = "%FC"
const sCopyrightDS = "           2004 xxxxxxxxx"
const sFontName = "Arial" '"Tempus Sans ITC"


' Constants that can be used with the DrawText nFormat parameter
' (from Microsoft documentation)
Const DT_TOP = &H0		' Specifies top-justified text (single line only).
Const DT_LEFT = &H0		' Aligns text flush-left.
Const DT_CENTER = &H1		' Centers text horizontally.
Const DT_RIGHT = &H2		' Aligns text flush-right.
Const DT_VCENTER = &H4		' Specifies vertically centered text (single line only).
Const DT_BOTTOM = &H8		' Specifies bottom-justified text (single line only).
Const DT_WORDBREAK = &H10	' Specifies word-breaking.
Const DT_SINGLELINE = &H20	' Specifies single line only. Carriage returns and
				' linefeeds do not break the line.
Const DT_EXPANDTABS = &H40	' Expands tab characters. The default number of characters
				' per tab is eight.
Const DT_TABSTOP = &H80		' Sets tab stops. The high-order byte of nFormat is the
				' number of characters for each tab.
Const DT_NOCLIP = &H100		' Draws without clipping.
Const DT_EXTERNALLEADING = &H200 'Includes the fonts external leading in the line height.
				' Normally, external leading is not included in the
				' height of a line of text.
Const DT_CALCRECT = &H400	' Determines the width and height of the rectangle.
				' If there are multiple lines of text, DrawText will use
				' the width of the rectangle pointed to by lpRect and
				' extend the base of the rectangle to bound the last line
				' of text. If there is only one line of text, DrawText
				' will modify the right side of the rectangle so that it
				' bounds the last character in the line. In either case,
				' DrawText returns the height of the formatted text, but
				' does not draw the text.
Const DT_NOPREFIX = &H800	' Turns off processing of prefix characters. Normally,
				' DrawText interprets the ampersand (&) mnemonic-prefix
				' character as a directive to underscore the character
				' that follows, and the two-ampersand (&&) mnemonic-prefix
				' characters as a directive to print a single ampersand.
				' By specifying DT_NOPREFIX, this processing is turned off.
Const DT_INTERNAL = &H1000	' Uses the system font to calculate text metrics.
Const DT_EDITCONTROL = &H2000	' Duplicates the text-displaying characteristics of a
				' multiline edit control. Specifically, the average
				' character width is calculated in the same manner as for
				' an edit control, and the function does not display a
				' partially visible last line.
Const DT_PATH_ELLIPSIS = &H4000	' For displayed text, replaces characters in the middle
				' of the string with ellipses so that the result fits in
				' the specified rectangle. If the string contains backslash
				' (\) characters, DT_PATH_ELLIPSIS preserves as much as
				' possible of the text after the last backslash.  
Const DT_END_ELLIPSIS = &H8000	' For displayed text, replaces the end of a string with
				' ellipses so that the result fits in the specified
				' rectangle. Any word (not at the end of the string) that
				' goes beyond the limits of the rectangle is truncated
				' without ellipses.
Const DT_MODIFYSTRING = &H10000	' Modifies the specified string to match the displayed
				' text. This value has no effect unless DT_END_ELLIPSIS
				' or DT_PATH_ELLIPSIS is specified.
Const DT_RTLREADING = &H20000	' Layout in right-to-left reading order for bi-directional
				' text when the font selected into the hdc is a Hebrew or
				' Arabic font. The default reading order for all text is
				' left-to-right.
Const DT_WORD_ELLIPSIS = &H40000 ' Truncates any word that does not fit in the rectangle
				' and adds ellipses. Compare with DT_END_ELLIPSIS and
				' DT_PATH_ELLIPSIS.
Const DT_NOFULLWIDTHCHARBREAK = &H80000 ' Prevents a line break at a DBCS (double-wide
				' character string), so that the line-breaking rule is
				' equivalent to SBCS strings. For example, this can be
				' used in Korean windows, for more readability of icon
				' labels. This value has no effect unless DT_WORDBREAK
				' is specified.
Const DT_HIDEPREFIX = &H100000	' Ignores the ampersand (&) prefix character in the text.
				' The letter that follows will not be underlined, but
				' other mnemonic-prefix characters are still processed. 
Const DT_PREFIXONLY = &H200000	' Draws only an underline at the position of the character
				' following the ampersand (&) prefix character. Does not
				' draw any character in the string. 

const Transparent = -1		
dim Grey, White, Black, LtGrey
Grey = RGB(192,192,192)
White = RGB(255,255,255)
Black = RGB(0,0,0)
LtGrey = RGB(240,240,240)

const ForReading = 1, ForWriting = 2

const yes=1, no=0

dim alb, pic, picNew, kPos, rect, k
dim card_w, card_h, max_img_w, max_img_h, max_img, img_septum, img_w_pixels, img_h_pixels, img_base_pixels, center_dist, card_w_pixels, card_h_pixels
dim img_right, img_left, img_center_dist_pixels
dim img_v_dist
dim n, i

dim txtFilename, newComment, s
dim fs, f
dim image_area_pixels, text_area_pixels, copyright_area_pixels
dim frame_card_area, frame_image_area, frame_text_area, frame_images
dim card_color, image_area_color, text_area_color

dim image_area_x, image_area_y, image_area_w, image_area_h
dim text_area_x, text_area_y, text_area_w, text_area_h
dim image_right_pixels, image_left_pixels
dim text_print, text_multiline 
dim crop_image
dim font_size_large, font_size_medium, font_size_small
dim stereocard_name, output_file_ext

set image_area_pixels = CreateObject("MyAlbum.rect")
set text_area_pixels = CreateObject("MyAlbum.rect")
set copyright_area_pixels = CreateObject("MyAlbum.rect")
set image_left_pixels = CreateObject("MyAlbum.rect")
set image_right_pixels = CreateObject("MyAlbum.rect")

const new_holmes=0, new_holmes_cabinet=1, thorpe_6x13= 2, holmes=3, eurocard=4, realist_mount= 5

dim stereoview_type, output_file_type
stereoview_type = 5

App.ClearTrace

dim input_box_text
input_box_text = "Please enter the steroview type number:"&Chr(10)&Chr(10)&"Thorpe Digital Stereoview Standard"&Chr(10)&"  0 -> Holmes Card Format"&Chr(10)&"  1 -> Holmes Cabinet Card Format"&Chr(10)&"  2 -> 6x13 Card Format"&Chr(10)&Chr(10)&"Traditional stereocard formats"&Chr(10)&"  3 -> Holmes Stereocard"&Chr(10)&"  4 -> 6x13 Eurocard"&Chr(10)&"  5 -> Realist mount (101x41 R-mount)"&Chr(10)
stereoview_type = InputBox(input_box_text, "Stereoview type", "0")

if stereoview_type<>"" then

output_file_ext="jpg"
input_box_text = "Please enter the output file type:"&Chr(10)&Chr(10)&"  0 -> JPEG (default)"&Chr(10)&"  1 -> BMP"&Chr(10)&"  2 -> PNG"&Chr(10)
output_file_type = InputBox(input_box_text, "Output file type", "0")

if output_file_type<>"" then


Select Case output_file_type
Case "0"
  output_file_ext="jpg"
Case "1"
  output_file_ext="bmp"
Case "2"
  output_file_ext="png"
Case Else
  output_file_ext="jpg"
End Select

app.ClearTrace

'Card: refers to the entire stereoview or stereocard
crop_image = False
frame_images = False
font_size_large = 1/2 'mm
font_size_medium = 1/3 'mm
text_multiline = False

if stereoview_type>=10 then
  stereoview_type = stereoview_type-10
  crop_image = True
end if


Select Case stereoview_type

'Thorpe Digital Stereoview Standard, Holmes Card Format
Case "0"
  'Measures in inchs
  stereocard_name = "newholmes"
  card_w = 6
  card_h = 4
  max_img_w = 2+11/16
  max_img_h = 3+ 1/8
  img_septum =   1/8

  image_area_x = 0
  image_area_y = 1/2
  image_area_w = 6
  image_area_h = 3+1/2

  text_area_x = 1/4
  text_area_y = 3/16
  text_area_w = 5+1/2
  text_area_h = 5/16

  text_print = True

  frame_card_area=  True
  frame_image_area= False
  frame_text_area=  False

  card_color= LtGrey
  image_area_color= Transparent
  text_area_color= Transparent

'Thorpe Digital Stereoview Standard, Holmes Cabinet Card Format
Case "1"
  'Measures in inches
  stereocard_name = "newholmescabinet"
  card_w = 6
  card_h = 4
  max_img_w = 2+11/16
  max_img_h =  3+5/8
  img_septum =   1/8

  image_area_x = 0
  image_area_y = 0
  image_area_w = 6
  image_area_h = 4

  text_area_x = 1/4
  text_area_y = 3/16
  text_area_w = 5+1/2
  text_area_h = 5/16

  text_print = False

  frame_card_area=  True
  frame_image_area= False
  frame_text_area=  False

  card_color= White
  image_area_color= Transparent
  text_area_color= Transparent

'Thorpe Digital Stereoview Standard, 6x13 Card Format
Case "2"
  'Measures in inches
  stereocard_name = "new6x13"
  card_w = 6
  card_h = 4
  max_img_w = 2
  max_img_h = 2
  img_septum = 3/4

  image_area_x =  7/16
  image_area_y = 1+7/16
  image_area_w = 5+1/8  '13 cm
  image_area_h = 2+3/8  ' 6 cm

  text_area_x = 1/4
  text_area_y = 3/16
  text_area_w = 5+1/2
  text_area_h = 5/16   ' Should be 1+1/16 but is changed to 6/16 for a better text layout

  text_print = True

  frame_card_area=  True
  frame_image_area= True
  frame_text_area=  False

  card_color= Grey
  image_area_color= White
  text_area_color= Transparent

'Traditional Holmes Stereocard
Case "3"
  'Measures in inches
  stereocard_name = "holmes"
  card_w = 7
  card_h = 3+1/2
  max_img_w = 3
  max_img_h = 3
  img_septum = 1/8

  image_area_x = 7/16
  image_area_y = 0
  image_area_w = 6+1/8
  image_area_h = 3+1/2

'  Area at the left end, vertical text
'  text_area_x = 1/16
'  text_area_y = 1/16
'  text_area_w = 3/8
'  text_area_h = 3+3/8

  text_area_x = 3+1/2+1/16
  text_area_y = 3+1/4
  text_area_w = 3
  text_area_h = 1/4

  text_print = True
  text_multiline = True
  font_size_large = 1/7 'mm
  font_size_medium = 1/7 'mm

  frame_card_area=  True
  frame_image_area= False
  frame_text_area=  False

  card_color= White
  image_area_color= Transparent
  text_area_color= Transparent

'6x13 Eurocard
Case "4"
  'Measures in inches
  stereocard_name = "eurocard"
  card_w = 5+1/8  '13 cm
  card_h = 2+3/8  ' 6 cm
  max_img_w = 2
  max_img_h = 2
  img_septum = 3/4

  image_area_x = 0
  image_area_y = 0
  image_area_w = 5+1/8  '13 cm
  image_area_h = 2+3/8  ' 6 cm

  text_area_x = 1/4
  text_area_y = 3/16
  text_area_w = 5+1/2
  text_area_h = 1+1/16

  text_print = False

  frame_card_area=  True
  frame_image_area= False
  frame_text_area=  False

  card_color= White
  image_area_color= Transparent
  text_area_color= Transparent

'Realist mount (101x41 R-mount)
Case "5"
  'Measures in mm
  stereocard_name = "rmount"
  card_w = 101
  card_h = 41
  max_img_w = 33  '7p (european)
  max_img_h = 23
  img_septum = 62-max_img_w

  image_area_x = 0
  image_area_y = 0
  image_area_w = 101
  image_area_h = 41

  text_area_x = 39.5
  text_area_y = 9
  text_area_w = 22.5
  text_area_h = 23

  text_print = True
  text_multiline = True
  font_size_large = 0.2 'mm
  font_size_medium = 0.2 'mm

  frame_card_area =  True
  frame_image_area = False
  frame_text_area =  False
  frame_images = True

  card_color = White
  image_area_color = Transparent
  text_area_color = Transparent

Case Else
  'Measures in inchs
  stereocard_name = "parallel"
  card_w = 6
  card_h = 4
  max_img_w = (card_w/2)-1/4
  max_img_h = card_h-1/4
  img_septum =   1/8

  image_area_x = 0
  image_area_y = 0
  image_area_w = card_w
  image_area_h = card_h

  text_print = False

  frame_card_area=  True
  frame_image_area= False
  frame_text_area=  False

  card_color= White
  image_area_color= Transparent
  text_area_color= Transparent

End Select

center_dist = max_img_w+img_septum



set alb = app.GetCurrentAlbum
if not alb is nothing then

n = alb.NbPicture
app.Trace alb.NbSelectedPicture & " selected pictures in this album", -1, TRACE_INFORMATION
For i = 0 to n-1
 Set pic = alb.GetPicture(i)
 If pic.bSelected Then
   App.Trace "Processing picture " & pic.sFileName & "...", -1, TRACE_ARROW
   
   'Look for a comment file to include a comment to the actual picture
   If pic.sComment = "" Then
      k = instrrev( pic.sFileName, "." )
      txtFilename = left( pic.sFileName, k) & "txt"

      Set fs = CreateObject("Scripting.FileSystemObject")
      If fs.FileExists(txtFilename) Then
         app.Trace "Existe el fichero" & txtFilename
         Set f = fs.OpenTextFile( txtFilename, ForReading )
         newComment = ""
         Do While f.AtEndOfStream <> True
            s = f.ReadLine
            newComment = newComment & s & Chr(13) & Chr(10)
         Loop
         pic.sComment = newComment
         f.Close
      End If
   End If

  ' Copy current picture to the cliboard
  pic.copy(0)

  ' Removed: MyAlbum supports now JPS files
  'Change the file type for .jps and .bms files and update the thumbnail
  'If UCase(Right(pic.sShortFileName,3))="JPS" Then
  '  pic.lStatus = (pic.lStatus And &HFFFFFFFE) Or &H00000002
  '  pic.UpdateThumbnail(1)
  'End If

  If UCase(Right(pic.sShortFileName,3))="BMS" Then
    pic.lStatus = (pic.lStatus And &HFFFFFFFE) Or &H00000001
    pic.UpdateThumbnail(1)
  End If


  ' Calculate new picture size
  img_h_pixels = pic.h
  img_w_pixels = pic.w/2

  if crop_image then
    if ((max_img_w/img_w_pixels) > (max_img_h/img_h_pixels)) then
      img_base_pixels = img_w_pixels
      max_img = max_img_w
    else
      img_base_pixels = img_h_pixels
      max_img = max_img_h
    end if
      
  else
    if ((max_img_w/img_w_pixels) > (max_img_h/img_h_pixels)) then
      img_base_pixels = img_h_pixels
      max_img = max_img_h
    else
      img_base_pixels = img_w_pixels
      max_img = max_img_w
    end if
  end if

  card_w_pixels = (card_w * img_base_pixels)/max_img
  card_h_pixels = (card_h * img_base_pixels)/max_img
  img_center_dist_pixels = (center_dist * img_base_pixels)/max_img

  'Calculate image_area and text_area in pixels
  image_area_pixels.x = (image_area_x * img_base_pixels)/max_img
  image_area_pixels.y = (image_area_y * img_base_pixels)/max_img
  image_area_pixels.w = (image_area_w * img_base_pixels)/max_img
  image_area_pixels.h = (image_area_h * img_base_pixels)/max_img

  text_area_pixels.x = (text_area_x * img_base_pixels)/max_img
  text_area_pixels.y = (text_area_y * img_base_pixels)/max_img
  text_area_pixels.w = (text_area_w * img_base_pixels)/max_img
  text_area_pixels.h = (text_area_h * img_base_pixels)/max_img


  ' Create an empty new picture with the calculated size
  app.Trace "  Creating a new picture " & round(card_w_pixels) & "x" & round(card_h_pixels)
  set picNew = alb.NewPicture( card_w_pixels, card_h_pixels, 32, card_color )

  set rect = CreateObject("MyAlbum.rect")
  'Frame the card
  rect.x = 0
  rect.y = 0
  rect.w = card_w_pixels
  rect.h = card_h_pixels

  if frame_card_area then
    if not picNew.DrawRectangle( rect, 1, 0, card_color, 4, rect.w, rect.h ) then app.Trace "  Caution: DrawRectangle failed.", -1, TRACE_WARNING
  end if

  'Frame the text area
  if frame_text_area then
    if not picNew.DrawRectangle( text_area_pixels, 1, 0, text_area_color, 4, text_area_pixels.w, text_area_pixels.h ) then app.Trace "  Caution: DrawRectangle failed.", -1, TRACE_WARNING
  end if
  set rect = Nothing

  'Frame the image area
  if frame_image_area then
    if not picNew.DrawRectangle( image_area_pixels, 1, 0, image_area_color, 4, image_area_pixels.w, image_area_pixels.h ) then app.Trace "  Caution: DrawRectangle failed.", -1, TRACE_WARNING
  end if

dim new_img_h_pixels, new_img_w_pixels

  if crop_image then
    if ((max_img_w/img_w_pixels) > (max_img_h/img_h_pixels)) then 'crop vertical
      new_img_h_pixels = (max_img_h * img_base_pixels)/max_img

      img_left = pic.copyRect( img_w_pixels, (img_h_pixels-new_img_h_pixels)/2, pic.w, new_img_h_pixels+((img_h_pixels-new_img_h_pixels)/2), -1 )
      picNew.paste image_area_pixels.x+(image_area_pixels.w-img_center_dist_pixels-img_w_pixels)/2, image_area_pixels.y+(image_area_pixels.h-new_img_h_pixels)/2

      img_right = pic.copyRect( 0, (img_h_pixels-new_img_h_pixels)/2, img_w_pixels, new_img_h_pixels+((img_h_pixels-new_img_h_pixels)/2), -1 )
      picNew.paste image_area_pixels.x+(image_area_pixels.w+img_center_dist_pixels-img_w_pixels)/2, image_area_pixels.y+(image_area_pixels.h-new_img_h_pixels)/2

      img_h_pixels = new_img_h_pixels

    else 'crop horizontal
      new_img_w_pixels = (max_img_w * img_base_pixels)/max_img

      img_left = pic.copyRect( img_w_pixels+(img_w_pixels-new_img_w_pixels)/2, 0, img_w_pixels+new_img_w_pixels+((img_w_pixels-new_img_w_pixels)/2), img_h_pixels, -1 )
      picNew.paste image_area_pixels.x+(image_area_pixels.w-img_center_dist_pixels-new_img_w_pixels)/2, image_area_pixels.y+(image_area_pixels.h-img_h_pixels)/2

      img_right = pic.copyRect( (img_w_pixels-new_img_w_pixels)/2, 0, new_img_w_pixels+((img_w_pixels-new_img_w_pixels)/2), img_h_pixels, -1 )
      picNew.paste image_area_pixels.x+(image_area_pixels.w+img_center_dist_pixels-new_img_w_pixels)/2, image_area_pixels.y+(image_area_pixels.h-img_h_pixels)/2

      img_w_pixels = new_img_w_pixels

    end if
  else 'No croping
    ' Copy left image and paste the current picture into the new picture
    img_left = pic.copyRect( img_w_pixels, 0, pic.w, img_h_pixels, -1 )
    if not picNew.paste( image_area_pixels.x+(image_area_pixels.w-img_center_dist_pixels-img_w_pixels)/2, image_area_pixels.y+(image_area_pixels.h-img_h_pixels)/2 ) then
       app.Trace "Error pasting left picture!", 255, TRACE_ERROR
    end if

    ' Copy right image and paste the current picture into the new picture
    img_right = pic.copyRect( 0, 0, img_w_pixels, img_h_pixels, -1 )
    if not picNew.paste( image_area_pixels.x+(image_area_pixels.w+img_center_dist_pixels-img_w_pixels)/2, image_area_pixels.y+(image_area_pixels.h-img_h_pixels)/2 ) then
       app.Trace "Error pasting right picture!", 255, TRACE_ERROR
    end if
  end if


  if frame_images then
    'Calculate individual left and right image_area in pixels
    image_left_pixels.x = image_area_pixels.x+(image_area_pixels.w-img_center_dist_pixels-img_w_pixels)/2
    image_left_pixels.y = image_area_pixels.y+(image_area_pixels.h-img_h_pixels)/2
    image_left_pixels.w = img_w_pixels
    image_left_pixels.h = img_h_pixels

    image_right_pixels.x = image_area_pixels.x+(image_area_pixels.w+img_center_dist_pixels-img_w_pixels)/2
    image_right_pixels.y = image_area_pixels.y+(image_area_pixels.h-img_h_pixels)/2
    image_right_pixels.w = img_w_pixels
    image_right_pixels.h = img_h_pixels

    'Frame left and right images area
    picNew.DrawRectangle image_right_pixels, 1, 0, -1, 4, image_right_pixels.w, image_right_pixels.h
    picNew.DrawRectangle image_left_pixels, 1, 0, -1, 4, image_left_pixels.w, image_left_pixels.h
  end if

  ' Move the new picture just after the original picture
  alb.MovePicture picNew, i, True


if text_print then
  ' Write the picture comment
  Dim SearchString, SearchChar, MyPos, CommentLine01, CommentLine02, CommentLine03
  dim font, font_size

  if text_multiline then
    'Print first comment line

    'Print comment lines
    font_size = CStr(card_w_pixels*(font_size_large/14))
    font = sFontName & "," & font_size & ",0,400,0,0,0"
    picNew.drawText alb.ExpandMacro( pic, sCommentDS ), text_area_pixels, font, Black, Transparent,  DT_END_ELLIPSIS or DT_NOPREFIX
  else


  SearchString = alb.ExpandMacro( pic, sCommentDS )
  SearchChar = Chr(13)

  CommentLine01 = ""
  CommentLine02 = ""
  CommentLine03 = ""

  MyPos = Instr(1, SearchString, SearchChar)
  If MyPos > 0 Then
    CommentLine01 = Left(SearchString, MyPos-1)

    SearchString = Right(SearchString, Len(SearchString)-MyPos-1)
    MyPos = Instr(1, SearchString, SearchChar)   
    If MyPos > 0 Then
      CommentLine02 = Left(SearchString, MyPos-1)

      SearchString = Right(SearchString, Len(SearchString)-MyPos-1)
      MyPos = Instr(1, SearchString, SearchChar)   
      If MyPos > 0 Then
        CommentLine03 = Left(SearchString, MyPos-1)
      Else
        CommentLine03 = SearchString
      End If
    Else
      CommentLine02 = SearchString
    End If
  Else
    CommentLine01 = SearchString
  End If

  'Print comment lines
  if CommentLine01 <> "" then
    font_size = CStr(card_w_pixels*(font_size_large/14))
    font = sFontName & "," & font_size & ",0,400,0,0,0"
    picNew.drawText CommentLine01, text_area_pixels, font, Black, Transparent, DT_TOP or DT_SINGLELINE or DT_LEFT or DT_NOPREFIX
  end if

  if CommentLine02 <> "" then
    font_size = CStr(card_w_pixels*(font_size_medium/14))
    font = sFontName & "," & font_size & ",0,400,0,0,0"
    picNew.drawText CommentLine02, text_area_pixels, font, Black, Transparent, DT_BOTTOM or DT_SINGLELINE or DT_LEFT or DT_NOPREFIX
  end if
    
  if CommentLine03 <> "" then
    font_size = CStr(card_w_pixels*(font_size_medium/14))
    font = sFontName & "," & font_size & ",0,400,0,0,0"
    picNew.drawText CommentLine03, text_area_pixels, font, Black, Transparent, DT_BOTTOM or DT_SINGLELINE or DT_RIGHT or DT_NOPREFIX
  end if
  
  ' Print copyright info vertically on the left of the card
  if sCopyrightDS <> "" and (stereoview_type = 0 or stereoview_type = 2) then
    font_size = CStr(card_w_pixels*(font_size_medium/14))
    font = sFontName & "," & font_size & ",0,400,0,0,0,900,900"
    Dim wM
    wM = CInt(font_size) / 2
    copyright_area_pixels.x = wM
    copyright_area_pixels.y = wM
    copyright_area_pixels.w = card_w_pixels - wM
    copyright_area_pixels.h = card_h_pixels - wM
    picNew.drawText alb.ExpandMacro( pic, sCopyrightDS ), copyright_area_pixels, font, Black, Transparent, DT_BOTTOM or DT_SINGLELINE or DT_LEFT or DT_NOPREFIX or DT_NOCLIP
  end if  

end if
end if    

  Dim filename
  filename = alb.ExpandMacro( pic, "%RP" )
  k = instrrev( filename, "." )
  ' The new picture will have the stereocard name appended to its name
  filename = left( filename, k-1 ) & "_" &  stereocard_name & "." & output_file_ext
  app.Trace "  Saving picture '" & filename & "'..."
  if not picNew.Save( filename, True ) then
    app.Trace "Error saving picture!", 255, TRACE_ERROR
  else
   picNew.UpdateThumbnail(1)
  end if


  ''' Copy the whole picture to the clipboard
  ''picNew.copy(0)
  ''alb.DeletePicture picNew

  ''set picNew = Nothing

  ''' Now create a "real" picture with it's name derived from the original picture name
  ''dim filename
  ''filename = alb.ExpandMacro( pic, "%RP" ) 'pic.sFileName
  ''k = instrrev( filename, "." )
  ''' The new picture will have   "stereocard_name" appended to its name and will be a JPEG picture
  ''filename = left( filename, k-1 ) & "_" &   stereocard_name & "." & output_file_ext
  ' Paste the picture on the clipboard to a new picture and save it
  ''if not alb.paste( filename ) then app.Trace "Error pasting picture!", 255, TRACE_ERROR

  alb.redraw
End If

Next

End If

end if 'if output_file_type<>"" then

end if 'if stereoview_type<>"" then

' Release all rectangle objects
set image_area_pixels = Nothing
set text_area_pixels = Nothing
set copyright_area_pixels = Nothing
set image_left_pixels = Nothing
set image_right_pixels = Nothing

app.Trace "Done!", -1, TRACE_GREENDOT
